Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2019-02-27 04:02:02 +0300
committerCampbell Barton <ideasman42@gmail.com>2019-02-27 04:26:49 +0300
commit1079742db92576d79ec89a28d95336aff847a82a (patch)
tree2e440e498c20d3205c2a64eedf4f84bf57abcb84 /source/blender/draw/engines/eevee/eevee_private.h
parent918941483f7ec5fc6320d345c755e953b963c710 (diff)
Cleanup: rename lamp -> light
Diffstat (limited to 'source/blender/draw/engines/eevee/eevee_private.h')
-rw-r--r--source/blender/draw/engines/eevee/eevee_private.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/source/blender/draw/engines/eevee/eevee_private.h b/source/blender/draw/engines/eevee/eevee_private.h
index a5695fa3a4c..0d168bb2793 100644
--- a/source/blender/draw/engines/eevee/eevee_private.h
+++ b/source/blender/draw/engines/eevee/eevee_private.h
@@ -352,10 +352,10 @@ typedef struct EEVEE_Light {
float spotsize, spotblend, radius, shadowid;
float rightvec[3], sizex;
float upvec[3], sizey;
- float forwardvec[3], lamptype;
+ float forwardvec[3], light_type;
} EEVEE_Light;
/* Special type for elliptic area lamps, matches lamps_lib.glsl */
#define LAMPTYPE_AREA_ELLIPSE 100.0f
typedef struct EEVEE_Shadow {
@@ -405,7 +405,7 @@ typedef struct EEVEE_ShadowCasterBuffer {
} EEVEE_ShadowCasterBuffer;
/* ************ LIGHT DATA ************* */
-typedef struct EEVEE_LampsInfo {
+typedef struct EEVEE_LightsInfo {
int num_light, cache_num_light;
int num_cube_layer, cache_num_cube_layer;
int num_cascade_layer, cache_num_cascade_layer;
@@ -436,15 +436,15 @@ typedef struct EEVEE_LampsInfo {
/* Pointers only. */
struct EEVEE_ShadowCasterBuffer *shcaster_frontbuffer;
struct EEVEE_ShadowCasterBuffer *shcaster_backbuffer;
-} EEVEE_LampsInfo;
+} EEVEE_LightsInfo;
-/* EEVEE_LampsInfo->shadow_casters_flag */
+/* EEVEE_LightsInfo->shadow_casters_flag */
enum {
SHADOW_CASTER_PRUNED = (1 << 0),
SHADOW_CASTER_UPDATED = (1 << 1),
};
-/* EEVEE_LampsInfo->update_flag */
+/* EEVEE_LightsInfo->update_flag */
enum {
LIGHT_UPDATE_SHADOW_CUBE = (1 << 0),
};
@@ -646,7 +646,7 @@ typedef struct EEVEE_CommonUniformBuffer {
int sss_toggle; /* bool */
/* Specular */
int spec_toggle; /* bool */
- /* Lamps */
+ /* Lights */
int la_num_light; /* int */
/* Probes */
int prb_num_planar; /* int */
@@ -676,8 +676,8 @@ typedef struct EEVEE_ClipPlanesUniformBuffer {
/* ************** SCENE LAYER DATA ************** */
typedef struct EEVEE_ViewLayerData {
- /* Lamps */
- struct EEVEE_LampsInfo *lamps;
+ /* Lights */
+ struct EEVEE_LightsInfo *lights;
struct GPUUniformBuffer *light_ubo;
struct GPUUniformBuffer *shadow_ubo;
@@ -737,7 +737,7 @@ typedef struct EEVEE_ShadowCascadeData {
/* Theses are the structs stored inside Objects.
* It works with even if the object is in multiple layers
* because we don't get the same "Object *" for each layer. */
-typedef struct EEVEE_LampEngineData {
+typedef struct EEVEE_LightEngineData {
DrawData dd;
bool need_update;
@@ -748,7 +748,7 @@ typedef struct EEVEE_LampEngineData {
struct EEVEE_ShadowCubeData scd;
struct EEVEE_ShadowCascadeData scad;
} data;
-} EEVEE_LampEngineData;
+} EEVEE_LightEngineData;
typedef struct EEVEE_LightProbeEngineData {
DrawData dd;
@@ -827,8 +827,8 @@ EEVEE_ObjectEngineData *EEVEE_object_data_get(Object *ob);
EEVEE_ObjectEngineData *EEVEE_object_data_ensure(Object *ob);
EEVEE_LightProbeEngineData *EEVEE_lightprobe_data_get(Object *ob);
EEVEE_LightProbeEngineData *EEVEE_lightprobe_data_ensure(Object *ob);
-EEVEE_LampEngineData *EEVEE_lamp_data_get(Object *ob);
-EEVEE_LampEngineData *EEVEE_lamp_data_ensure(Object *ob);
+EEVEE_LightEngineData *EEVEE_light_data_get(Object *ob);
+EEVEE_LightEngineData *EEVEE_light_data_ensure(Object *ob);
EEVEE_WorldEngineData *EEVEE_world_data_get(World *wo);
EEVEE_WorldEngineData *EEVEE_world_data_ensure(World *wo);
@@ -352,10 +352,10 @@ typedef struct EEVEE_Light {
} EEVEE_Light;
-/* Special type for elliptic area lamps, matches lamps_lib.glsl */
+/* Special type for elliptic area lights, matches lamps_lib.glsl */
#define LAMPTYPE_AREA_ELLIPSE 100.0f
typedef struct EEVEE_Shadow {